Harvey
=====
![](http://i.imgur.com/raSkNrr.png?1)

image: http://www.buylocalexperts.com/sanantonio/images/stories/buy-local-legal-expert.png

Harvey is a command line legal expert who manages license for you.